==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-VE/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Campos Personalizados',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Acerca de Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets te permite crear grupos de campos personalizados que están frecuentemente siendo reutilizados para tipos específicos de modelos de activos.',
    'custom_format'             => 'Formato regex personalizado...',
    'encrypt_field'      	        => 'Encriptar el valor de este campo en la base de datos',
    'encrypt_field_help'      => 'ADVERTENCIA: Encriptar un campo hace que no pueda ser buscado.',
    'encrypted'      	        => 'Encriptado',
    'fieldset'      	        => 'Grupo de Campos',
    'qty_fields'      	      => 'Campos de Cantidad',
    'fieldsets'      	        => 'Grupo de Campos',
    'fieldset_name'           => 'Nombre del Grupo de Campos',
    'field_name'              => 'Nombre del Campo',
    'field_values'            => 'Valores del Campo',
    'field_values_help'       => 'Añadir opciones seleccionables, una por línea. Líneas en blanco además de la primera serán ignoradas.',
    'field_element'           => 'Elemento de Formulario',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato Personalizado de Regex',
    'field_custom_format_help'     => 'Este campo te permite usar una expresión regex para la validación. Debería empezar como "regex:" - por ejemplo, para validar que un campo personalizado contiene un IMEI válido (15 dígitos numéricos), tú usarías <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligatorio',
    'req'   		              => 'Obl.',
    'used_by_models'   		    => 'Usado por Modelos',
    'order'   		            => 'Orden',
    'create_fieldset'         => 'Nuevo Fieldset',
    'create_field'            => 'Nuevo Campo Personalizado',
    'value_encrypted'      	        => 'El valor de este campo está encriptado en la base de datos. Sólo los administradores podrán ver el valor desencriptado',
    'show_in_email'     => '¿Incluirá el valor de este campo en las notificaciones por correo de asignaciones de activos? Ten en cuenta que los campos cifrados no se pueden incluir en los correos electrónicos.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-VE/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Campos Personalizados',
    'manage'                    => 'Manage',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Acerca de Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Encriptar el valor de este campo en la base de datos',
    'encrypt_field_help'      => 'ADVERTENCIA: Encriptar un campo hace que no pueda ser buscado.',
    'encrypted'      	        => 'Encriptado',
    'fieldset'      	        => 'Grupo de Campos',
    'qty_fields'      	      => 'Campos de Cantidad',
    'fieldsets'      	        => 'Grupo de Campos',
    'fieldset_name'           => 'Nombre del Grupo de Campos',
    'field_name'              => 'Nombre del Campo',
    'field_values'            => 'Valores del Campo',
    'field_values_help'       => 'Añadir opciones seleccionables, una por línea. Líneas en blanco además de la primera serán ignoradas.',
    'field_element'           => 'Elemento de Formulario',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato Personalizado de Regex',
    'field_custom_format_help'     => 'Este campo te permite usar una expresión regex para la validación. Debería empezar como "regex:" - por ejemplo, para validar que un campo personalizado contiene un IMEI válido (15 dígitos numéricos), tú usarías <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligatorio',
    'req'   		              => 'Obl.',
    'used_by_models'   		    => 'Usado por Modelos',
    'order'   		            => 'Orden',
    'create_fieldset'         => 'Nuevo Fieldset',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Nuevo Campo Personalizado',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'El valor de este campo está encriptado en la base de datos. Sólo los administradores podrán ver el valor desencriptado',
    'show_in_email'     => '¿Incluirá el valor de este campo en las notificaciones por correo de asignaciones de activos? Ten en cuenta que los campos cifrados no se pueden incluir en los correos electrónicos.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
